@@ -225,6 +225,7 @@ typedef struct globus_i_gsc_handle_opts_s
     globus_bool_t                           delayed_passive;
     globus_bool_t                           passive_only;
     int                                     perf_frequency;
+    int                                     retr_perf_frequency;
     int                                     restart_frequency;
     globus_gsc_layout_t                     layout;
     globus_size_t                           block_size;
@@ -288,7 +289,8 @@ typedef struct globus_i_gsc_op_s
 
     globus_gridftp_server_control_stat_t *  stat_info;
     int                                     stat_count;
-
+    globus_mutex_t                          stat_lock;
+    
     /* stuff for resource */
     int                                     uid;
     int                                     gid_count;
@@ -320,7 +322,7 @@ typedef struct globus_i_gsc_op_s
     globus_bool_t                           aborted;
     void *                                  abort_user_arg;
     void *                                  user_arg;
-
+    
     globus_i_gsc_data_t *                   data_destroy_obj;
 } globus_i_gsc_op_t;
 
@@ -607,7 +609,8 @@ globus_i_gsc_mlsx_line(
     int                                 stat_count,
     const char *                        mlsx_fact_string,
     uid_t                               uid,
-    const char *                        base_path);
+    const char *                        base_path,
+    globus_bool_t                       indent);
 
 void
 globus_i_guc_command_data_destroy(
